i16le

Struct i16le 

pub struct i16le(/* private fields */);
The 16-bit little endian signed integer type.

Implementations

Source

impl i16le

pub const fn new(value: i16) -> i16le

Convert a native byte order integer into an endianness specific integer.

pub const fn get(&self) -> i16

Convert the endianness specific integer into native byte order.

pub fn set(&mut self, value: i16)

Convert a native byte order integer and store it in this endianness specific integer.

pub const fn is_zero(&self) -> bool

Check if the value is zero.

pub const fn from_be_bytes(bytes: [u8; 2]) -> i16le

Creates an integer value from its representation as a byte array in big endian.