pub struct i16le(/* private fields */);Expand description
The 16-bit little endian signed integer type.
Implementations
Sourceimpl i16le
impl i16le
Sourcepub const fn new(value: i16) -> i16le
pub const fn new(value: i16) -> i16le
Convert a native byte order integer into an endianness specific integer.
Sourcepub fn set(&mut self, value: i16)
pub fn set(&mut self, value: i16)
Convert a native byte order integer and store it in this endianness specific integer.
Sourcepub const fn from_be_bytes(bytes: [u8; 2]) -> i16le
pub const fn from_be_bytes(bytes: [u8; 2]) -> i16le
Creates an integer value from its representation as a byte array in big endian.